.. -*- coding: utf-8 -*-

.. _`CG_fiber-dataset`:

CG fiber dataset
================

MD trajectory showing the self-assembly of an amphiphilic molecule.

The topology is contained in the PSF file (CHARMM format). The
trajectory is contained in the DCD file (CHARMM/NAMD format).


Notes
-----

Data set characteristics:

 :size: 213 MB
 :number of trajectories: 1
 :creator: Aysenur Iscen
 :URL:  `<https://figshare.com/articles/126chains_dcd/7259915>`_
 :license: `CC-BY 4.0 <https://creativecommons.org/licenses/by/4.0/legalcode>`_
